{*****************************************************************}
{*                                                               *}
{*  Bitmap property editor v1.0                                  *}
{*  Copyright(c) 1997, African Dancer                            *}
{*                                                               *}
{*  This is originally part of a simple image viewer I made in   *}
{*  1995, with help from the book Instant Delphi. Now, inspired  *}
{*  by Dr. Bob's image property editor, I make this a replace-   *}
{*  ment of the property editor (with some of code stolen from   *}
{*  Dr. Bob)                                                     *}
{*                                                               *}
{*  New features:                                                *}
{*   * Automatic conversion from icon and metafiles to bitmap    *}
{*   * Template of Toolbar button images                         *}
{*   * Normal, glyph views                                       *}
{*                                                               *}
{*  Need help on full-screen view
{*      see procedure TImageForm.FileListClick(Sender: TObject); *}
{*      and procedure TImageForm.BtnViewClick(Sender: TObject);  *}
{*  Need help on built-in image editor for this property editor  *}
{*                                                               *}
{*  African Dancer: dancer@tieus.com                             *}
{*  Nov. 30, 1997, Vancouver                                     *}
{*                                                               *}
{*****************************************************************}

unit Iv_main;

interface

uses WinTypes, WinProcs, Classes, Graphics, Forms, Controls,
  FileCtrl, StdCtrls, ExtCtrls, Buttons, Spin, Tabs, TabNotBk;

type
  TImageForm = class(TForm)
    BtnOk: TBitBtn;
    BtnCancel: TBitBtn;
    DirList: TDirectoryListBox;
    FileList: TFileListBox;
    DriveCombo: TDriveComboBox;
    DriveTabSet: TTabSet;
    LabelPath: TLabel;
    LabelFile: TLabel;
    Bevel1: TBevel;
    LabelPalette: TLabel;
    SpinPalette: TSpinEdit;
    BtnPalette: TBitBtn;
    ViewTab: TTabbedNotebook;
    Bevel2: TBevel;
    Image: TImage;
    StretchCheck: TCheckBox;
    BtnView: TBitBtn;
    GlyphTestBtn1: TBitBtn;
    GlyphTestBtn2: TBitBtn;
    GlyphTestSpeed1: TSpeedButton;
    GlyphTestSpeed2: TSpeedButton;
    GlyphLabel1: TLabel;
    GlyphNo: TSpinEdit;
    TempInternet: TScrollBox;
    ti01: TSpeedButton;
    ti02: TSpeedButton;
    ti03: TSpeedButton;
    ti04: TSpeedButton;
    ti05: TSpeedButton;
    ti06: TSpeedButton;
    ti07: TSpeedButton;
    ti08: TSpeedButton;
    ti09: TSpeedButton;
    ti10: TSpeedButton;
    TempWord: TScrollBox;
    tw01: TSpeedButton;
    tw02: TSpeedButton;
    tw3: TSpeedButton;
    tw4: TSpeedButton;
    tw5: TSpeedButton;
    tw6: TSpeedButton;
    tw7: TSpeedButton;
    tw8: TSpeedButton;
    tw9: TSpeedButton;
    tw10: TSpeedButton;
    tw11: TSpeedButton;
    tw12: TSpeedButton;
    tw13: TSpeedButton;
    tw14: TSpeedButton;
    tw15: TSpeedButton;
    tw16: TSpeedButton;
    tw17: TSpeedButton;
    tw18: TSpeedButton;
    tw19: TSpeedButton;
    tw20: TSpeedButton;
    tw21: TSpeedButton;
    tw22: TSpeedButton;
    procedure DriveTabSetClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FileListClick(Sender: TObject);
    procedure FileListDblClick(Sender: TObject);
    procedure GlyphNoChange(Sender: TObject);
    procedure BtnViewClick(Sender: TObject);
    procedure DoStretch(Sender: TObject);
    procedure BtnPaletteClick(Sender: TObject);
    procedure LoadButton(Sender: TObject);
    procedure SetGlyph;
  end;

var
  ImageForm: TImageForm;

implementation

uses SysUtils, Iv_Full;

{$R *.DFM}

procedure TImageForm.FormCreate(Sender: TObject);
begin
  { Add a list of drives to DriveTabSet }
  DriveTabSet.Tabs:=DriveCombo.Items;
  DriveTabSet.TabIndex:=DriveCombo.ItemIndex;

  { When the first items is added, DriveTabSet will call OnClick event handler.
    To avoid the annoying error message, 'Drive not ready' (if drive A is not
    ready), set DriveTabSetClick as DriveTabSet's OnClick event handler after
    items are added and the current drive is set. }
  DriveTabSet.OnClick := DriveTabSetClick;
  TIVFullScreen.Create(nil)
end;

procedure TImageForm.DriveTabSetClick(Sender: TObject);
begin
  { Set the current drive }
  DirList.Drive:=DriveTabSet.Tabs[DriveTabSet.TabIndex][1]
end;

procedure TImageForm.FileListClick(Sender: TObject);
var
  FileExt: string[4];
  TempIcon: TIcon;
  TempWMF: TMetaFile;
begin
  if FileList.ItemIndex < 0
    then BtnOk.Enabled := False
    else begin
      try
        Screen.Cursor := crHourGlass;
        BtnOk.Enabled := True;
        try
          FileExt := UpperCase(ExtractFileExt(FileList.Filename));
          if (FileExt = '.BMP') then
            Image.Picture.LoadFromFile(FileList.Filename) else
          if FileExt = '.ICO' then
            try
              { Convert icon into bitmap graphic }
              TempIcon := TIcon.Create;
              TempIcon.LoadFromFile(FileList.FileName);
              Image.Picture.Bitmap := TBitmap.Create;
              Image.Picture.Bitmap.Width := TempIcon.Width;
              Image.Picture.Bitmap.Height := TempIcon.Height;
              Image.Picture.Bitmap.Canvas.Draw(1,1,TempIcon);
            finally
              TempIcon.Free;
            end else
          if FileExt = '.WMF' then
            try
              { Convert metafile graphic into bitmap graphic }
              TempWMF := TMetaFile.Create;
              TempWMF.LoadFromFile(FileList.FileName);
              Image.Picture.Bitmap := TBitmap.Create;
              Image.Picture.Bitmap.Width := TempWMF.Width;
              Image.Picture.Bitmap.Height := TempWMF.Height;
              Image.Picture.Bitmap.Canvas.Draw(1,1,TempWMF);
            finally
              TempWMF.Free;
            end;

          { Set LabelFile's caption to "filename.xxx (10 x 10)" }
          LabelFile.Caption := ExtractFilename(FileList.Filename) +
             Format(' (%d x %d)', [Image.Picture.Height, Image.Picture.Width]);

          { Paste the image to full-screen-view form }
          { Disabled. For some reason, the following codes generate error }
          {With IvFullScreen.Image1.Picture do
          begin
            Bitmap.Width := Image.Picture.Bitmap.Width;
            Bitmap.Height := Image.Picture.Bitmap.Height;
            Bitmap.Canvas.Draw(0,0, Image.Picture.Bitmap)
          end;}

          { Get the number of pallete entries }
          SpinPalette.value := RealizePalette(Image.Picture.Bitmap.Canvas.Handle);

          SetGlyph; { Set test buttons' glyph images }
        except
          Image.Picture.Free
        end
      finally
        Screen.Cursor := crDefault;
      end
    end
end;

procedure TImageForm.SetGlyph;
begin
   GlyphTestSpeed1.Glyph := Image.Picture.Bitmap;
   GlyphTestSpeed2.Glyph := Image.Picture.Bitmap;
   GlyphNo.Value := GlyphTestSpeed1.NumGlyphs;
   GlyphTestBtn1.Glyph := Image.Picture.Bitmap;
   GlyphTestBtn2.Glyph := Image.Picture.Bitmap
end;

procedure TImageForm.FileListDblClick(Sender: TObject);
begin
  ModalResult := mrOk
end;

procedure TImageForm.BtnViewClick(Sender: TObject);
begin
{  IvFullScreen.HorzScrollBar.Range := IvFullScreen.Image1.Picture.Width;
  IvFullScreen.VertScrollBar.Range := IvFullScreen.Image1.Picture.Height;
  IvFullScreen.ShowModal;}
end;

procedure TImageForm.GlyphNoChange(Sender: TObject);
begin
  { Change number of glyphs in test speedbuttons }
  GlyphTestSpeed1.NumGlyphs := GlyphNo.Value;
  GlyphTestSpeed2.NumGlyphs := GlyphNo.Value;
end;

procedure TImageForm.DoStretch(Sender: TObject);
begin
  Image.Stretch := StretchCheck.Checked;
end;

procedure TImageForm.BtnPaletteClick(Sender: TObject);
begin
  { change the number of palette entries }
  ResizePalette(Image.Picture.Bitmap.Palette, SpinPalette.value);

  SetGlyph;
end;

procedure TImageForm.LoadButton(Sender: TObject);
begin
  Image.Picture.Bitmap := (Sender as TSpeedButton).Glyph;
  SetGlyph; { Reset test buttons' images }
end;

end.
